# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/sku_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import sku_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/sku_service.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/billing/v1/sku_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a!yandex/cloud/billing/v1/sku.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\rGetSkuRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x08\x63urrency\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x03 \x01(\t\"\x9f\x01\n\x0fListSkusRequest\x12\x16\n\x08\x63urrency\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1d\n\tpage_size\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"W\n\x10ListSkusResponse\x12*\n\x04skus\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.billing.v1.Sku\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xef\x01\n\nSkuService\x12j\n\x03Get\x12&.yandex.cloud.billing.v1.GetSkuRequest\x1a\x1c.yandex.cloud.billing.v1.Sku\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/billing/v1/skus/{id}\x12u\n\x04List\x12(.yandex.cloud.billing.v1.ListSkusRequest\x1a).yandex.cloud.billing.v1.ListSkusResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/billing/v1/skusBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSKUREQUEST = _descriptor.Descriptor(
  name='GetSkuRequest',
  full_name='yandex.cloud.billing.v1.GetSkuRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.GetSkuRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='yandex.cloud.billing.v1.GetSkuRequest.currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.GetSkuRequest.billing_account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=259,
)


_LISTSKUSREQUEST = _descriptor.Descriptor(
  name='ListSkusRequest',
  full_name='yandex.cloud.billing.v1.ListSkusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='yandex.cloud.billing.v1.ListSkusRequest.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.ListSkusRequest.billing_account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.billing.v1.ListSkusRequest.filter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.billing.v1.ListSkusRequest.page_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.billing.v1.ListSkusRequest.page_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=421,
)


_LISTSKUSRESPONSE = _descriptor.Descriptor(
  name='ListSkusResponse',
  full_name='yandex.cloud.billing.v1.ListSkusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='skus', full_name='yandex.cloud.billing.v1.ListSkusResponse.skus', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.billing.v1.ListSkusResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=510,
)

_LISTSKUSRESPONSE.fields_by_name['skus'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2._SKU
DESCRIPTOR.message_types_by_name['GetSkuRequest'] = _GETSKUREQUEST
DESCRIPTOR.message_types_by_name['ListSkusRequest'] = _LISTSKUSREQUEST
DESCRIPTOR.message_types_by_name['ListSkusResponse'] = _LISTSKUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSkuRequest = _reflection.GeneratedProtocolMessageType('GetSkuRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSKUREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.sku_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.GetSkuRequest)
  })
_sym_db.RegisterMessage(GetSkuRequest)

ListSkusRequest = _reflection.GeneratedProtocolMessageType('ListSkusRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSKUSREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.sku_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListSkusRequest)
  })
_sym_db.RegisterMessage(ListSkusRequest)

ListSkusResponse = _reflection.GeneratedProtocolMessageType('ListSkusResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSKUSRESPONSE,
  '__module__' : 'yandex.cloud.billing.v1.sku_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListSkusResponse)
  })
_sym_db.RegisterMessage(ListSkusResponse)


DESCRIPTOR._options = None
_GETSKUREQUEST.fields_by_name['id']._options = None
_GETSKUREQUEST.fields_by_name['currency']._options = None
_LISTSKUSREQUEST.fields_by_name['currency']._options = None
_LISTSKUSREQUEST.fields_by_name['filter']._options = None
_LISTSKUSREQUEST.fields_by_name['page_size']._options = None
_LISTSKUSREQUEST.fields_by_name['page_token']._options = None

_SKUSERVICE = _descriptor.ServiceDescriptor(
  name='SkuService',
  full_name='yandex.cloud.billing.v1.SkuService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=513,
  serialized_end=752,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.billing.v1.SkuService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSKUREQUEST,
    output_type=yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2._SKU,
    serialized_options=b'\202\323\344\223\002\027\022\025/billing/v1/skus/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.billing.v1.SkuService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSKUSREQUEST,
    output_type=_LISTSKUSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/billing/v1/skus',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SKUSERVICE)

DESCRIPTOR.services_by_name['SkuService'] = _SKUSERVICE

# @@protoc_insertion_point(module_scope)
